=== modified file 'drizzled/base.h'
--- drizzled/base.h	2010-10-05 03:25:08 +0000
+++ drizzled/base.h	2010-11-02 09:28:14 +0000
@@ -25,6 +25,8 @@
  * @TODO Convert HA_XXX defines into enums and/or bitmaps
  */
 
+#include "definitions.h"
+
 #ifndef DRIZZLED_BASE_H
 #define DRIZZLED_BASE_H
 
@@ -494,7 +496,10 @@
 
 /* For number of records */
 typedef uint64_t	ha_rows;
-#define rows2double(A)	uint64_t2double(A)
+inline static double rows2double(ha_rows rows)
+{  
+  return uint64_t2double(rows);
+}
 
 #define HA_POS_ERROR	(~ (::drizzled::ha_rows) 0)
 #define HA_OFFSET_ERROR	(~ (::drizzled::internal::my_off_t) 0)
@@ -505,7 +510,10 @@
 #define MAX_FILE_SIZE	INT64_MAX
 #endif
 
-#define HA_VARCHAR_PACKLENGTH(field_length) ((field_length) < 256 ? 1 :2)
+inline static uint32_t ha_varchar_packlength(uint32_t field_length)
+{
+  return (field_length < 256 ? 1 :2);
+}
 
 
 } /* namespace drizzled */

=== modified file 'drizzled/calendar.cc'
--- drizzled/calendar.cc	2010-10-10 08:28:30 +0000
+++ drizzled/calendar.cc	2010-11-02 09:28:14 +0000
@@ -53,8 +53,21 @@
  * Private utility macro for enabling a switch between
  * Gregorian and Julian leap year date arrays.
  */
-#define __DAYS_IN_MONTH(y, c) (const uint32_t *) (IS_LEAP_YEAR((y),(c)) ? __leap_days_in_month : __normal_days_in_month)
-#define __DAYS_TO_END_MONTH(y, c) (const uint32_t *) (IS_LEAP_YEAR((y),(c)) ? __leap_days_to_end_month : __normal_days_to_end_month)
+inline static const uint32_t* days_in_month(uint32_t y, enum calendar c) 
+{
+  if (is_leap_year(y, c))
+    return __leap_days_in_month;
+  else
+    return __normal_days_in_month;
+}
+
+inline static const uint32_t* days_to_end_month(uint32_t y, enum calendar c) 
+{
+  if (is_leap_year(y, c))
+    return __leap_days_to_end_month;
+  else
+    return __normal_days_to_end_month;
+}
 
 
 /**
@@ -289,7 +302,7 @@
     return (day <= __normal_days_in_month[month - 1]);
   else
   {
-    const uint32_t *p_months= __DAYS_IN_MONTH(year, (enum calendar) GREGORIAN);
+    const uint32_t *p_months= days_in_month(year, (enum calendar) GREGORIAN);
     return (day <= p_months[1]);
   }
 }
@@ -303,7 +316,7 @@
  */
 uint32_t days_in_gregorian_year_month(uint32_t year, uint32_t month)
 {
-  const uint32_t *p_months= __DAYS_IN_MONTH(year, GREGORIAN);
+  const uint32_t *p_months= days_in_month(year, GREGORIAN);
   return p_months[month - 1];
 }
 

=== modified file 'drizzled/calendar.h'
--- drizzled/calendar.h	2010-10-10 08:28:30 +0000
+++ drizzled/calendar.h	2010-11-02 09:28:14 +0000
@@ -67,27 +67,6 @@
 #define GREGORIAN_DAYS_IN_100_YEARS UINT32_C(36524)
 #define GREGORIAN_DAYS_IN_4_YEARS   UINT32_C(1461)
 
-/**
- * Simple macro returning whether the supplied year
- * is a leap year in the supplied calendar.
- *
- * @param Year to evaluate
- * @param Calendar to use
- */
-#define IS_LEAP_YEAR(y, c) (days_in_year((y),(c)) == 366)
-
-/**
- * Simple macro returning whether the supplied year
- * is a leap year in the Gregorian proleptic calendar.
- */
-#define IS_GREGORIAN_LEAP_YEAR(y) (days_in_year_gregorian((y)) == 366)
-
-/**
- * Simple macro returning whether the supplied year
- * is a leap year in the Julian proleptic calendar.
- */
-#define IS_JULIAN_LEAP_YEAR(y) (days_in_year_julian((y)) == 366)
-
 namespace drizzled
 {
 
@@ -96,12 +75,13 @@
  */
 enum calendar
 {
-  GREGORIAN= 1
-, JULIAN= 2
-, HEBREW= 3
-, ISLAM= 4
+  GREGORIAN= 1, 
+  JULIAN= 2, 
+  HEBREW= 3, 
+  ISLAM= 4
 };
 
+
 /**
  * Calculates the Julian Day Number from the year, month 
  * and day supplied for a Gregorian Proleptic calendar date.
@@ -185,10 +165,6 @@
  */
 uint32_t days_in_year_julian(uint32_t year);
 
-#define NUM_LEAP_YEARS(y, c) ((c) == GREGORIAN \
-    ? number_of_leap_years_gregorian((y)) \
-    : number_of_leap_years_julian((y)))
-
 /**
  * Returns the number of leap years that have
  * occurred in the Julian Proleptic calendar
@@ -216,6 +192,13 @@
  */
 uint32_t days_in_gregorian_year_month(uint32_t year, uint32_t month);
 
+inline static bool num_leap_years(uint32_t y, enum calendar c) 
+{
+  return (c == GREGORIAN                
+          ? number_of_leap_years_gregorian(y) 
+          : number_of_leap_years_julian(y));
+}
+
 /**
  * Returns the number of the day in a week.
  *
@@ -328,6 +311,36 @@
  */
 uint32_t months_to_year_month(uint32_t months);
 
+/**
+ * Simple function returning whether the supplied year
+ * is a leap year in the supplied calendar.
+ *
+ * @param Year to evaluate
+ * @param Calendar to use
+ */
+inline static bool is_leap_year(uint32_t y, enum calendar c)
+{
+  return (days_in_year(y, c) == 366);
+}
+
+/**
+ * Simple function returning whether the supplied year
+ * is a leap year in the Gregorian proleptic calendar.
+ */
+inline static bool is_gregorian_leap_year(uint32_t y)
+{
+  return (days_in_year_gregorian(y) == 366);
+}
+
+/**
+ * Simple function returning whether the supplied year
+ * is a leap year in the Julian proleptic calendar.
+ */
+inline static bool is_julian_leap_year(uint32_t y) 
+{
+  return (days_in_year_julian(y) == 366);
+}
+
 } /* namespace drizzled */
 
 #endif /* DRIZZLED_CALENDAR_H */

=== modified file 'drizzled/charset_info.h'
--- drizzled/charset_info.h	2010-10-06 17:22:20 +0000
+++ drizzled/charset_info.h	2010-11-02 09:28:14 +0000
@@ -21,6 +21,7 @@
 #define DRIZZLED_CHARSET_INFO_H
 
 #include <sys/types.h>
+#include <cstddef>
 
 namespace drizzled
 {
@@ -65,8 +66,12 @@
 #define MY_CS_TOOSMALL4 -104  /* Need at least 4 bytes: wc_mb and mb_wc */
 #define MY_CS_TOOSMALL5 -105  /* Need at least 5 bytes: wc_mb and mb_wc */
 #define MY_CS_TOOSMALL6 -106  /* Need at least 6 bytes: wc_mb and mb_wc */
-/* A helper macros for "need at least n bytes" */
-#define MY_CS_TOOSMALLN(n)    (-100-(n))
+
+/* A helper function for "need at least n bytes" */
+inline static int my_cs_toosmalln(int n)
+{
+  return -100-n;
+}
 
 #define MY_SEQ_INTTAIL	1
 #define MY_SEQ_SPACES	2
@@ -659,51 +664,222 @@
 #define	_MY_X	0200	/* heXadecimal digit */
 
 
-#define	my_isascii(c)	(!((c) & ~0177))
-#define	my_toascii(c)	((c) & 0177)
-#define my_tocntrl(c)	((c) & 31)
-#define my_toprint(c)	((c) | 64)
-#define my_toupper(s,c)	(char) ((s)->to_upper[(unsigned char) (c)])
-#define my_tolower(s,c)	(char) ((s)->to_lower[(unsigned char) (c)])
-#define	my_isalpha(s, c)  (((s)->ctype+1)[(unsigned char) (c)] & (_MY_U | _MY_L))
-#define	my_isupper(s, c)  (((s)->ctype+1)[(unsigned char) (c)] & _MY_U)
-#define	my_islower(s, c)  (((s)->ctype+1)[(unsigned char) (c)] & _MY_L)
-#define	my_isdigit(s, c)  (((s)->ctype+1)[(unsigned char) (c)] & _MY_NMR)
-#define	my_isxdigit(s, c) (((s)->ctype+1)[(unsigned char) (c)] & _MY_X)
-#define	my_isalnum(s, c)  (((s)->ctype+1)[(unsigned char) (c)] & (_MY_U | _MY_L | _MY_NMR))
-#define	my_isspace(s, c)  (((s)->ctype+1)[(unsigned char) (c)] & _MY_SPC)
-#define	my_ispunct(s, c)  (((s)->ctype+1)[(unsigned char) (c)] & _MY_PNT)
-#define	my_isprint(s, c)  (((s)->ctype+1)[(unsigned char) (c)] & (_MY_PNT | _MY_U | _MY_L | _MY_NMR | _MY_B))
-#define	my_isgraph(s, c)  (((s)->ctype+1)[(unsigned char) (c)] & (_MY_PNT | _MY_U | _MY_L | _MY_NMR))
-#define	my_iscntrl(s, c)  (((s)->ctype+1)[(unsigned char) (c)] & _MY_CTR)
+inline static bool my_isascii(char c)      
+{
+  return (!(c & ~0177));
+}
+
+inline static char my_toascii(char c)
+{
+  return (c & 0177);
+}
+
+inline static char my_tocntrl(char c) 
+{
+  return (c & 31);
+}
+
+inline static char my_toprint(char c)
+{
+  return (c | 64);
+}
+
+inline static char my_toupper(const charset_info_st *s, char c)
+{
+  return (char)(s->to_upper[(unsigned char)c]);
+}
+
+inline static char my_tolower(const charset_info_st *s, char c)
+{
+  return (char)(s->to_lower[(unsigned char)c]);
+}
+
+inline static bool my_isalpha(const charset_info_st *s, char c)
+{
+  return ((s->ctype+1)[(unsigned char)c] & (_MY_U | _MY_L));
+}
+
+inline static bool my_isupper(const charset_info_st *s, char c)
+{
+  return ((s->ctype+1)[(unsigned char)c] & _MY_U);
+}
+
+inline static bool my_islower(const charset_info_st *s, char c)
+{
+  return ((s->ctype+1)[(unsigned char)c] & _MY_L);
+}
+
+inline static bool my_isdigit(const charset_info_st *s, char c)
+{
+  return ((s->ctype+1)[(unsigned char)c] & _MY_NMR);
+}
+
+inline static bool my_isxdigit(const charset_info_st *s, char c)
+{
+  return ((s->ctype+1)[(unsigned char)c] & _MY_X);
+}
+
+inline static bool my_isalnum(const charset_info_st *s, char c) 
+{
+  return ((s->ctype+1)[(unsigned char)c] & (_MY_U | _MY_L | _MY_NMR));
+}
+
+inline static bool my_isspace(const charset_info_st *s, char c)
+{
+  return ((s->ctype+1)[(unsigned char)c] & _MY_SPC);
+}
+
+inline static bool my_ispunct(const charset_info_st *s, char c)  
+{
+  return ((s->ctype+1)[(unsigned char)c] & _MY_PNT);
+}
+
+inline static bool my_isprint(const charset_info_st *s, char c)  
+{
+  return ((s->ctype+1)[(unsigned char)c] & (_MY_PNT | _MY_U | _MY_L | _MY_NMR | _MY_B));
+}
+
+inline static bool my_isgraph(const charset_info_st *s, char c)
+{
+  return ((s->ctype+1)[(unsigned char)c] & (_MY_PNT | _MY_U | _MY_L | _MY_NMR));
+}
+
+inline static bool my_iscntrl(const charset_info_st *s, char c)  
+{
+  return ((s->ctype+1)[(unsigned char)c] & _MY_CTR);
+}
 
 /* Some macros that should be cleaned up a little */
-#define my_isvar(s,c)                 (my_isalnum(s,c) || (c) == '_')
-#define my_isvar_start(s,c)           (my_isalpha(s,c) || (c) == '_')
-
-#define my_binary_compare(s)	      ((s)->state  & MY_CS_BINSORT)
-#define use_strnxfrm(s)               ((s)->state  & MY_CS_STRNXFRM)
-#define my_strnxfrm(cs, d, dl, s, sl) \
-   ((cs)->coll->strnxfrm((cs), (d), (dl), (dl), (s), (sl), MY_STRXFRM_PAD_WITH_SPACE))
-#define my_strnncoll(s, a, b, c, d) ((s)->coll->strnncoll((s), (a), (b), (c), (d), 0))
-#define my_like_range(s, a, b, c, d, e, f, g, h, i, j) \
-   ((s)->coll->like_range((s), (a), (b), (c), (d), (e), (f), (g), (h), (i), (j)))
-#define my_wildcmp(cs,s,se,w,we,e,o,m) ((cs)->coll->wildcmp((cs),(s),(se),(w),(we),(e),(o),(m)))
-#define my_strcasecmp(s, a, b)        ((s)->coll->strcasecmp((s), (a), (b)))
-#define my_charpos(cs, b, e, num)     (cs)->cset->charpos((cs), (const char*) (b), (const char *)(e), (num))
-
-
-#define use_mb(s)                     ((s)->cset->ismbchar != NULL)
-#define my_ismbchar(s, a, b)          ((s)->cset->ismbchar((s), (a), (b)))
-#define my_mbcharlen(s, a)            ((s)->cset->mbcharlen((s),(a)))
-
-#define my_caseup_str(s, a)           ((s)->cset->caseup_str((s), (a)))
-#define my_casedn_str(s, a)           ((s)->cset->casedn_str((s), (a)))
-#define my_strntol(s, a, b, c, d, e)  ((s)->cset->strntol((s),(a),(b),(c),(d),(e)))
-#define my_strntoul(s, a, b, c, d, e) ((s)->cset->strntoul((s),(a),(b),(c),(d),(e)))
-#define my_strntoll(s, a, b, c, d, e) ((s)->cset->strntoll((s),(a),(b),(c),(d),(e)))
-#define my_strntoull(s, a, b, c,d, e) ((s)->cset->strntoull((s),(a),(b),(c),(d),(e)))
-#define my_strntod(s, a, b, c, d)     ((s)->cset->strntod((s),(a),(b),(c),(d)))
+inline static bool my_isvar(const charset_info_st *s, char c)
+{
+  return (my_isalnum(s,c) || (c) == '_');
+}
+
+inline static bool my_isvar_start(const charset_info_st *s, char c)
+{
+  return (my_isalpha(s,c) || (c) == '_');
+}
+
+inline static bool my_binary_compare(const charset_info_st *s)
+{
+  return (s->state  & MY_CS_BINSORT);
+}
+
+inline static bool use_strnxfrm(const charset_info_st *s)
+{
+  return (s->state & MY_CS_STRNXFRM);
+}
+
+inline static size_t my_strnxfrm(const charset_info_st *cs, 
+                                 unsigned char *dst, 
+                                 const size_t dstlen, 
+                                 const unsigned char *src, 
+                                 const uint32_t srclen)
+{
+  return (cs->coll->strnxfrm(cs, dst, dstlen, dstlen, src, srclen, MY_STRXFRM_PAD_WITH_SPACE));
+}
+
+inline static int my_strnncoll(const charset_info_st *cs, 
+                               const unsigned char *s, 
+                               const size_t slen, 
+                               const unsigned char *t,
+                               const size_t tlen) 
+{
+  return (cs->coll->strnncoll(cs, s, slen, t, tlen, 0));
+}
+
+inline static bool my_like_range(const charset_info_st *cs,
+                                 const char *ptr, const size_t ptrlen,
+                                 const char escape, 
+                                 const char w_one,
+                                 const char w_many, 
+                                 const size_t reslen, 
+                                 char *minstr, char *maxstr, 
+                                 size_t *minlen, size_t *maxlen)
+{
+  return (cs->coll->like_range(cs, ptr, ptrlen, escape, w_one, w_many, reslen, 
+                               minstr, maxstr, minlen, maxlen));
+}
+
+inline static int my_wildcmp(const charset_info_st *cs,
+                             const char *str, const char *strend,
+                             const char *w_str, const char *w_strend,
+                             const int escape,
+                             const int w_one, const int w_many) 
+{
+  return (cs->coll->wildcmp(cs, str, strend, w_str, w_strend, escape, w_one, w_many));
+}
+
+inline static int my_strcasecmp(const charset_info_st *cs, const char *s, const char *t)
+{
+  return (cs->coll->strcasecmp(cs, s, t));
+}
+
+template <typename CHAR_T>
+inline static size_t my_charpos(const charset_info_st *cs, 
+                                const CHAR_T *b, const CHAR_T* e, size_t num)
+{
+  return (cs->cset->charpos(cs, (const char*) b, (const char *)e, num));
+} // fixme!!!
+
+inline static bool use_mb(const charset_info_st *cs)
+{
+  return (cs->cset->ismbchar != NULL);
+}
+
+inline static unsigned int  my_ismbchar(const charset_info_st *cs, const char *a, const char *b)
+{
+  return (cs->cset->ismbchar(cs, a, b));
+}
+
+inline static unsigned int my_mbcharlen(const charset_info_st *cs, uint32_t c)
+{
+  return (cs->cset->mbcharlen(cs, c));
+}
+
+
+inline static size_t my_caseup_str(const charset_info_st *cs, char *src)
+{
+  return (cs->cset->caseup_str(cs, src));
+}
+
+inline static size_t my_casedn_str(const charset_info_st *cs, char *src)
+{
+  return (cs->cset->casedn_str(cs, src));
+}
+
+inline static long my_strntol(const charset_info_st *cs, 
+                              const char* s, const size_t l, const int base, char **e, int *err)
+{
+  return (cs->cset->strntol(cs, s, l, base, e, err));
+}
+
+inline static unsigned long my_strntoul(const charset_info_st *cs, 
+                                        const char* s, const size_t l, const int base, 
+                                        char **e, int *err)
+{
+  return (cs->cset->strntoul(cs, s, l, base, e, err));
+}
+
+inline static int64_t my_strntoll(const charset_info_st *cs, 
+                                 const char* s, const size_t l, const int base, char **e, int *err)
+{
+  return (cs->cset->strntoll(cs, s, l, base, e, err));
+}
+
+inline static int64_t my_strntoull(const charset_info_st *cs, 
+                                   const char* s, const size_t l, const int base, 
+                                   char **e, int *err)
+{
+  return (cs->cset->strntoull(cs, s, l, base, e, err));
+}
+
+
+inline static double my_strntod(const charset_info_st *cs, 
+                                char* s, const size_t l, char **e, int *err)
+{
+  return (cs->cset->strntod(cs, s, l, e, err));
+}
 
 int make_escape_code(const CHARSET_INFO * const cs, const char *escape);
 

=== modified file 'drizzled/ctype-utf8.cc'
--- drizzled/ctype-utf8.cc	2010-10-02 21:15:42 +0000
+++ drizzled/ctype-utf8.cc	2010-11-02 09:28:14 +0000
@@ -2111,7 +2111,7 @@
   else return MY_CS_ILUNI;
 
   if (r + count > e)
-    return MY_CS_TOOSMALLN(count);
+    return my_cs_toosmalln(count);
 
   switch (count) {
     /* Fall through all cases!!! */

=== modified file 'drizzled/definition/table.cc'
--- drizzled/definition/table.cc	2010-10-28 05:22:47 +0000
+++ drizzled/definition/table.cc	2010-11-02 09:28:14 +0000
@@ -2097,7 +2097,7 @@
   case DRIZZLE_TYPE_VARCHAR:
     setVariableWidth();
     return new (&mem_root) Field_varstring(ptr,field_length,
-                                      HA_VARCHAR_PACKLENGTH(field_length),
+                                      ha_varchar_packlength(field_length),
                                       null_pos,null_bit,
                                       field_name,
                                       field_charset);

=== modified file 'plugin/myisam/mi_checksum.cc'
--- plugin/myisam/mi_checksum.cc	2010-10-02 21:15:42 +0000
+++ plugin/myisam/mi_checksum.cc	2010-11-02 09:28:14 +0000
@@ -40,7 +40,7 @@
     }
     case FIELD_VARCHAR:
     {
-      uint32_t pack_length= HA_VARCHAR_PACKLENGTH(rec->length-1);
+      uint32_t pack_length= ha_varchar_packlength(rec->length-1);
       if (pack_length == 1)
         length= (ulong) *(unsigned char*) buf;
       else

=== modified file 'plugin/myisam/mi_dynrec.cc'
--- plugin/myisam/mi_dynrec.cc	2010-10-02 21:15:42 +0000
+++ plugin/myisam/mi_dynrec.cc	2010-11-02 09:28:14 +0000
@@ -997,7 +997,7 @@
       }
       else if (type == FIELD_VARCHAR)
       {
-        uint32_t pack_length= HA_VARCHAR_PACKLENGTH(rec->length -1);
+        uint32_t pack_length= ha_varchar_packlength(rec->length -1);
 	uint32_t tmp_length;
         if (pack_length == 1)
         {
@@ -1117,7 +1117,7 @@
       }
       else if (type == FIELD_VARCHAR)
       {
-        uint32_t pack_length= HA_VARCHAR_PACKLENGTH(rec->length -1);
+        uint32_t pack_length= ha_varchar_packlength(rec->length -1);
 	uint32_t tmp_length;
         if (pack_length == 1)
         {
@@ -1190,7 +1190,7 @@
     {
       if (type == FIELD_VARCHAR)
       {
-        uint32_t pack_length= HA_VARCHAR_PACKLENGTH(rec_length-1);
+        uint32_t pack_length= ha_varchar_packlength(rec_length-1);
         if (pack_length == 1)
         {
           length= (uint) *(unsigned char*) from;

